/*
 * textfunc.h
 *
 * Author:
 *       Ricardo Cerqueira      <rmc@rccn.net>
 *
 * This software is covered by the GNU public license, which should be in a file named
 * LICENSE acompanying this.
 *
 */

#define CTRL_C		'\003'
#define TEXT_FIELD_LEN	30
#define INT_FIELD_LEN	4

void CenterText(int line, char *text);
char *checkinput(int c, char *string, int length);
void pad(char *string, int length);
char *curs_addparam(WINDOW *win, int line, int length, char *buf);
void buildtag(char *buf, char *title, char *artist, char *album, char *year, char *comment, unsigned char *genre);
void display_help();
void view_tag(FILE *fp);
